===============
Metaprogramming
===============

Abstract classes and metaclasses.

Abstract Classes
----------------

.. automodule:: sigmaepsilon.core.abstract
    :members:

Metaclasses
-----------

.. automodule:: sigmaepsilon.core.meta
    :members: